@@ -1,4 +1,4 @@
-#!/usr/local/bin/python3.10
+#!/usr/local/bin/python3.11
 # Unix SMB/CIFS implementation.
 # Copyright (C) Andrew Bartlett <abartlet@samba.org> 2017
 #
@@ -47,12 +47,9 @@ import re
 class AuthLogTests(samba.tests.auth_log_base.AuthLogTestBase):
 
     def setUp(self):
-        super(AuthLogTests, self).setUp()
+        super().setUp()
         self.remoteAddress = os.environ["CLIENT_IP"]
 
-    def tearDown(self):
-        super(AuthLogTests, self).tearDown()
-
     def smb_connection(self, creds, use_spnego="yes", ntlmv2_auth="yes",
                        force_smb1=False):
         # the SMB bindings rely on having a s3 loadparm
